pub struct ClaimableRewardResponse {
pub amount: Uint256,
pub fee: Uint256,
}Fields
amount: Uint256fee: Uint256Trait Implementations
Sourceimpl Clone for ClaimableRewardResponse
impl Clone for ClaimableRewardResponse
Sourcefn clone(&self) -> ClaimableRewardResponse
fn clone(&self) -> ClaimableRewardResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClaimableRewardResponse
impl Debug for ClaimableRewardResponse
Sourceimpl<'de> Deserialize<'de> for ClaimableRewardResponse
impl<'de> Deserialize<'de> for ClaimableRewardResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ClaimableRewardResponse
impl JsonSchema for ClaimableRewardResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ClaimableRewardResponse
impl PartialEq for ClaimableRewardResponse
Sourceimpl Serialize for ClaimableRewardResponse
impl Serialize for ClaimableRewardResponse
impl StructuralPartialEq for ClaimableRewardResponse