pub struct GlobalDescriptor {
pub name: String,
pub module: String,
pub scalar_type: String,
pub required: bool,
pub default_expr: Option<String>,
pub computed_expr: Option<String>,
}Fields
name: Stringmodule: Stringscalar_type: Stringrequired: booldefault_expr: Option<String>computed_expr: Option<String>PyQL expression string for computed globals (e.g. select User filter .id = global current_user_id).
When set, the global is computed from this expression at query time rather than injected as a parameter.