pub fn compile_script(
query: &str,
schema: &SchemaDescriptor,
config: &SessionConfig,
) -> Result<Vec<Arc<CompiledQuery>>, PyQLError>Expand description
Every statement of a script, compiled in the order written.
A single statement comes back as a one-element list, and takes the cached path — so this is safe to call for any query, not only ones with semicolons in them.